==> haskell-hspec-expectations-0.8.2-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-expectations.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-expectations
version:              0.8.2
visibility:           public
id:                   hspec-expectations-0.8.2-CZLSJF4w7HVBfjdvGNFnpk
key:                  hspec-expectations-0.8.2-CZLSJF4w7HVBfjdvGNFnpk
license:              MIT
copyright:            (c) 2011-2015 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/hspec-expectations#readme
synopsis:             Catchy combinators for HUnit
description:
    Catchy combinators for HUnit: <https://github.com/hspec/hspec-expectations#readme>

category:             Testing
abi:                  c28c4e062b05b4161829905fa4dd4ead
exposed:              True
exposed-modules:
    Test.Hspec.Expectations Test.Hspec.Expectations.Contrib

hidden-modules:
    Test.Hspec.Expectations.Matcher Paths_hspec_expectations

import-dirs:          /usr/lib/ghc-8.8.3/site-local/hspec-expectations-0.8.2
library-dirs:         /usr/lib/ghc-8.8.3/site-local/hspec-expectations-0.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/hspec-expectations-0.8.2
hs-libraries:         HShspec-expectations-0.8.2-CZLSJF4w7HVBfjdvGNFnpk
depends:
    HUnit-1.6.0.0-KRZf8ATQTYB1fCFucEZucy base-4.13.0.0
    call-stack-0.2.0-GQbBpuFoFEmI0HN2xwBVyc

haddock-interfaces:
    /usr/share/doc/haskell-hspec-expectations/html/hspec-expectations.haddock

haddock-html:         /usr/share/doc/haskell-hspec-expectations/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-expectations-0.8.2-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-expectations.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-expectations
version:              0.8.2
visibility:           public
id:                   hspec-expectations-0.8.2-7RqMaTKnPbBBxd5tHbs06S
key:                  hspec-expectations-0.8.2-7RqMaTKnPbBBxd5tHbs06S
license:              MIT
copyright:            (c) 2011-2015 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/hspec/hspec-expectations#readme
synopsis:             Catchy combinators for HUnit
description:
    Catchy combinators for HUnit: <https://github.com/hspec/hspec-expectations#readme>

category:             Testing
abi:                  6a9a8825e08b75c86b36edecf01245ed
exposed:              True
exposed-modules:
    Test.Hspec.Expectations Test.Hspec.Expectations.Contrib

hidden-modules:
    Test.Hspec.Expectations.Matcher Paths_hspec_expectations

import-dirs:          /usr/lib/ghc-8.8.3/site-local/hspec-expectations-0.8.2
library-dirs:         /usr/lib/ghc-8.8.3/site-local/hspec-expectations-0.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/hspec-expectations-0.8.2
hs-libraries:         HShspec-expectations-0.8.2-7RqMaTKnPbBBxd5tHbs06S
depends:
    HUnit-1.6.0.0-I2MmbBeZarmFuj7otDSV2j base-4.13.0.0
    call-stack-0.2.0-KAf2NG7gVRMGRbumjnZjkq

haddock-interfaces:
    /usr/share/doc/haskell-hspec-expectations/html/hspec-expectations.haddock

haddock-html:         /usr/share/doc/haskell-hspec-expectations/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
